summaryrefslogtreecommitdiffstats
path: root/share/extensions
diff options
context:
space:
mode:
authorAlexandre Prokoudine <alexandre.prokoudine@gmail.com>2010-06-05 15:13:09 +0000
committerAlexandre Prokoudine <avp@darkroom>2010-06-05 15:13:09 +0000
commitecf5b4bf16313a5e3c5b079b916e1905a3cb9b8d (patch)
tree4fbc1b7525a15e0d89a62ca64b656a0e9416fc01 /share/extensions
parentAdding a character to a superscript or subscript no longer resets (diff)
downloadinkscape-ecf5b4bf16313a5e3c5b079b916e1905a3cb9b8d.tar.gz
inkscape-ecf5b4bf16313a5e3c5b079b916e1905a3cb9b8d.zip
Typo fix by Yuri Chornoivan
(bzr r9482)
Diffstat (limited to 'share/extensions')
-rw-r--r--share/extensions/Inkscape.pm8
-rwxr-xr-xshare/extensions/interp_att_g.py2
-rw-r--r--share/extensions/test/inkweb-debug.js2
-rw-r--r--share/extensions/webslicer_create_group.inx4
-rw-r--r--share/extensions/webslicer_create_rect.inx4
-rw-r--r--share/extensions/webslicer_export.inx4
6 files changed, 12 insertions, 12 deletions
diff --git a/share/extensions/interp_att_g.py b/share/extensions/interp_att_g.py
index 503e4ec60..f23edaf36 100755
--- a/share/extensions/interp_att_g.py
+++ b/share/extensions/interp_att_g.py
@@ -29,7 +29,7 @@ class InterpAttG(inkex.Effect):
self.OptionParser.add_option("-o", "--att-other",
action="store", type="string",
dest="att_other",
- help="Other atribute (for a limited UI).")
+ help="Other attribute (for a limited UI).")
self.OptionParser.add_option("-t", "--att-other-type",
action="store", type="string",
dest="att_other_type",
diff --git a/share/extensions/test/inkweb-debug.js b/share/extensions/test/inkweb-debug.js
index 3dd3a4541..a4035503a 100644
--- a/share/extensions/test/inkweb-debug.js
+++ b/share/extensions/test/inkweb-debug.js
@@ -253,7 +253,7 @@ InkWeb.__logSequence = function ( msg ) {
InkWeb.logToString = function (conf) {
/* Show the log in a formated string.
- ** conf atributes:
+ ** conf attributes:
** format: a string to format the log itens.
** formatError: to format the error log itens.
** sep: the log itens separator string.
diff --git a/share/extensions/webslicer_create_group.inx b/share/extensions/webslicer_create_group.inx
index 6352c2066..2238a0901 100644
--- a/share/extensions/webslicer_create_group.inx
+++ b/share/extensions/webslicer_create_group.inx
@@ -6,8 +6,8 @@
<dependency type="executable" location="extensions">webslicer_create_group.py</dependency>
<dependency type="executable" location="extensions">inkex.py</dependency>
<_param name="about" type="description">Layout Group is only about to help a better code generation (if you need it). To use this, you must to select some "Slicer rectangles" first.</_param>
- <param name="html-id" type="string" _gui-text="HTML id atribute:"></param>
- <param name="html-class" type="string" _gui-text="HTML class atribute:"></param>
+ <param name="html-id" type="string" _gui-text="HTML id attribute:"></param>
+ <param name="html-class" type="string" _gui-text="HTML class attribute:"></param>
<param name="width-unity" type="enum" _gui-text="Width unit:">
<_item value="px">Pixel (fixed)</_item>
<_item value="percent">Percent (relative to parent size)</_item>
diff --git a/share/extensions/webslicer_create_rect.inx b/share/extensions/webslicer_create_rect.inx
index 035b3439e..acf440cca 100644
--- a/share/extensions/webslicer_create_rect.inx
+++ b/share/extensions/webslicer_create_rect.inx
@@ -32,8 +32,8 @@
<param name="palette-size" type="int" min="2" max="256" _gui-text="Palette size:">256</param>
</page>
<page name="tabHTML" gui-text="HTML">
- <param name="html-id" type="string" _gui-text="HTML id atribute:"></param>
- <param name="html-class" type="string" _gui-text="HTML class atribute:"></param>
+ <param name="html-id" type="string" _gui-text="HTML id attribute:"></param>
+ <param name="html-class" type="string" _gui-text="HTML class attribute:"></param>
<_param name="help-gif" type="description">Options for HTML export</_param>
<param name="layout-disposition" type="enum" _gui-text="Layout disposition:">
<_item value="bg-el-norepeat">Positioned html block element with the image as Background</_item>
diff --git a/share/extensions/webslicer_export.inx b/share/extensions/webslicer_export.inx
index eeb753add..3a7324370 100644
--- a/share/extensions/webslicer_export.inx
+++ b/share/extensions/webslicer_export.inx
@@ -5,8 +5,8 @@
<dependency type="executable" location="extensions">webslicer_effect.py</dependency>
<dependency type="executable" location="extensions">webslicer_export.py</dependency>
<dependency type="executable" location="extensions">inkex.py</dependency>
- <_param name="about" type="description">All sliced images, and optionally code, will be generated as you had configured and saved to one directory.</_param>
- <param name="dir" type="string" _gui-text="Directory path to export:"></param>
+ <_param name="about" type="description">All sliced images, and optionaly code, will be generated as you had configured and saved to one directory.</_param>
+ <param name="dir" type="string" _gui-text="Directory path to export"></param>
<param name="create-dir" type="boolean" _gui-text="Create directory, if it does not exists">false</param>
<param name="with-code" type="boolean" _gui-text="With HTML and CSS">true</param>
<effect needs-live-preview="false">
diff --git a/share/extensions/Inkscape.pm b/share/extensions/Inkscape.pm
index b87762c0d..3e9027baa 100644
--- a/share/extensions/Inkscape.pm
+++ b/share/extensions/Inkscape.pm
@@ -166,14 +166,14 @@ sub generateSearchRegExp {
=head3 setElAttribute
# Setting an atribute in a tag localizated it's id:
$svg->setElAttribute {id=>'myDrawing'}, 'width', $w * 2;
# Setting an atribute in a tag localizated it's position:
$svg->setElAttribute {tag=>'svg',pos=>0}, 'width', $w * 2;
# Setting an atribute in some tags localizated by atributes:
$svg->setElAttribute {tag=>'circle',r=>10}, 'r', 50;
-This method will set an atribute in a tag or in a colection of tags, selected
+This method will set an attribute in a tag or in a colection of tags, selected
by the localizator hash.
=cut
@@ -166,14 +166,14 @@ sub generateSearchRegExp {
=head3 setElAttribute
- # Setting an atribute in a tag localizated it's id:
+ # Setting an attribute in a tag localizated it's id:
$svg->setElAttribute {id=>'myDrawing'}, 'width', $w * 2;
@@ -166,14 +166,14 @@ sub generateSearchRegExp {
$svg->setElAttribute {id=>'myDrawing'}, 'width', $w * 2;
- # Setting an atribute in a tag localizated it's position:
+ # Setting an attribute in a tag localizated it's position:
$svg->setElAttribute {tag=>'svg',pos=>0}, 'width', $w * 2;
@@ -166,14 +166,14 @@ sub generateSearchRegExp {
$svg->setElAttribute {tag=>'svg',pos=>0}, 'width', $w * 2;
- # Setting an atribute in some tags localizated by atributes:
+ # Setting an attribute in some tags localizated by attributes:
$svg->setElAttribute {tag=>'circle',r=>10}, 'r', 50;